@@ -32,39 +32,11 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.exchange import Exchange as ExchangeSchema
-from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
-from snaptrade_client.model.brokerage_type import BrokerageType as BrokerageTypeSchema
-from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization as BrokerageAuthorizationSchema
-from snaptrade_client.model.price import Price as PriceSchema
-from snaptrade_client.model.brokerage_authorization_meta import BrokerageAuthorizationMeta as BrokerageAuthorizationMetaSchema
 from snaptrade_client.model.options_position import OptionsPosition as OptionsPositionSchema
-from snaptrade_client.model.brokerage import Brokerage as BrokerageSchema
-from snaptrade_client.model.brokerage_symbol import BrokerageSymbol as BrokerageSymbolSchema
-from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
-from snaptrade_client.model.brokerage_exchanges import BrokerageExchanges as BrokerageExchangesSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
-from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
-from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
 from snaptrade_client.model.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse as Model500UnexpectedExceptionResponseSchema
-from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
 
-from snaptrade_client.type.brokerage import Brokerage
-from snaptrade_client.type.brokerage_authorization_meta import BrokerageAuthorizationMeta
-from snaptrade_client.type.security_type import SecurityType
-from snaptrade_client.type.currency import Currency
-from snaptrade_client.type.brokerage_type import BrokerageType
-from snaptrade_client.type.brokerage_exchanges import BrokerageExchanges
-from snaptrade_client.type.price import Price
 from snaptrade_client.type.options_position import OptionsPosition
-from snaptrade_client.type.options_symbol import OptionsSymbol
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.brokerage_symbol import BrokerageSymbol
-from snaptrade_client.type.us_exchange import USExchange
-from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
-from snaptrade_client.type.brokerage_authorization import BrokerageAuthorization
 from snaptrade_client.type.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse
-from snaptrade_client.type.universal_symbol import UniversalSymbol
 
 from . import path
 
@@ -239,9 +211,10 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -305,6 +278,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -366,7 +340,7 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
     ) -> typing.Union[
@@ -467,6 +441,7 @@ class ListOptionHoldings(BaseApi):
         account_id: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -482,6 +457,7 @@ class ListOptionHoldings(BaseApi):
         return await self._alist_option_holdings_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def list_option_holdings(
@@ -517,6 +493,7 @@ class ApiForget(BaseApi):
         account_id: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -532,6 +509,7 @@ class ApiForget(BaseApi):
         return await self._alist_option_holdings_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def get(
