@@ -32,42 +32,10 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.exchange import Exchange as ExchangeSchema
-from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
-from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
-from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
-from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
-from snaptrade_client.model.price import Price as PriceSchema
-from snaptrade_client.model.action import Action as ActionSchema
-from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
-from snaptrade_client.model.filled_units import FilledUnits as FilledUnitsSchema
-from snaptrade_client.model.cancelled_units import CancelledUnits as CancelledUnitsSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
-from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
-from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
 from snaptrade_client.model.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse as Model500UnexpectedExceptionResponseSchema
-from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
-from snaptrade_client.model.open_units import OpenUnits as OpenUnitsSchema
-from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus as AccountOrderRecordStatusSchema
 
-from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
-from snaptrade_client.type.time_in_force import TimeInForce
-from snaptrade_client.type.security_type import SecurityType
-from snaptrade_client.type.filled_units import FilledUnits
-from snaptrade_client.type.stop_price import StopPrice
-from snaptrade_client.type.currency import Currency
-from snaptrade_client.type.price import Price
-from snaptrade_client.type.order_type import OrderType
-from snaptrade_client.type.action import Action
-from snaptrade_client.type.cancelled_units import CancelledUnits
-from snaptrade_client.type.options_symbol import OptionsSymbol
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.us_exchange import USExchange
-from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
-from snaptrade_client.type.open_units import OpenUnits
 from snaptrade_client.type.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse
-from snaptrade_client.type.universal_symbol import UniversalSymbol
 from snaptrade_client.type.account_order_record import AccountOrderRecord
 
 from . import path
@@ -101,6 +69,16 @@ class StateSchema(
     @schemas.classproperty
     def EXECUTED(cls):
         return cls("executed")
+
+
+class DaysSchema(
+    schemas.Int32Schema
+):
+
+
+    class MetaOapg:
+        format = 'int32'
+        inclusive_minimum = 1
 RequestRequiredQueryParams = typing_extensions.TypedDict(
     'RequestRequiredQueryParams',
     {
@@ -112,6 +90,7 @@ RequestOptionalQueryParams = typing_extensions.TypedDict(
     'RequestOptionalQueryParams',
     {
         'state': typing.Union[StateSchema, str, ],
+        'days': typing.Union[DaysSchema, decimal.Decimal, int, ],
     },
     total=False
 )
@@ -141,6 +120,12 @@ request_query_state = api_client.QueryParameter(
     schema=StateSchema,
     explode=True,
 )
+request_query_days = api_client.QueryParameter(
+    name="days",
+    style=api_client.ParameterStyle.FORM,
+    schema=DaysSchema,
+    explode=True,
+)
 # Path params
 AccountIdSchema = schemas.UUIDSchema
 RequestRequiredPathParams = typing_extensions.TypedDict(
@@ -256,6 +241,7 @@ class BaseApi(api_client.Api):
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
         state: typing.Optional[str] = None,
+        days: typing.Optional[int] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
@@ -268,6 +254,8 @@ class BaseApi(api_client.Api):
             _query_params["userSecret"] = user_secret
         if state is not None:
             _query_params["state"] = state
+        if days is not None:
+            _query_params["days"] = days
         if account_id is not None:
             _path_params["accountId"] = account_id
         args.query = query_params if query_params else _query_params
@@ -279,16 +267,17 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
         AsyncGeneratorResponse,
     ]:
         """
-        Get history of orders placed in account
+        List account orders
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -315,6 +304,7 @@ class BaseApi(api_client.Api):
             request_query_user_id,
             request_query_user_secret,
             request_query_state,
+            request_query_days,
         ):
             parameter_data = query_params.get(parameter.name, schemas.unset)
             if parameter_data is schemas.unset:
@@ -346,6 +336,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -407,7 +398,7 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
     ) -> typing.Union[
@@ -415,7 +406,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Get history of orders placed in account
+        List account orders
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -442,6 +433,7 @@ class BaseApi(api_client.Api):
             request_query_user_id,
             request_query_user_secret,
             request_query_state,
+            request_query_days,
         ):
             parameter_data = query_params.get(parameter.name, schemas.unset)
             if parameter_data is schemas.unset:
@@ -508,8 +500,10 @@ class GetUserAccountOrders(BaseApi):
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
         state: typing.Optional[str] = None,
+        days: typing.Optional[int] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -522,10 +516,12 @@ class GetUserAccountOrders(BaseApi):
             user_secret=user_secret,
             account_id=account_id,
             state=state,
+            days=days,
         )
         return await self._aget_user_account_orders_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def get_user_account_orders(
@@ -534,6 +530,7 @@ class GetUserAccountOrders(BaseApi):
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
         state: typing.Optional[str] = None,
+        days: typing.Optional[int] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -547,6 +544,7 @@ class GetUserAccountOrders(BaseApi):
             user_secret=user_secret,
             account_id=account_id,
             state=state,
+            days=days,
         )
         return self._get_user_account_orders_oapg(
             query_params=args.query,
@@ -562,8 +560,10 @@ class ApiForget(BaseApi):
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
         state: typing.Optional[str] = None,
+        days: typing.Optional[int] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -576,10 +576,12 @@ class ApiForget(BaseApi):
             user_secret=user_secret,
             account_id=account_id,
             state=state,
+            days=days,
         )
         return await self._aget_user_account_orders_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def get(
@@ -588,6 +590,7 @@ class ApiForget(BaseApi):
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
         state: typing.Optional[str] = None,
+        days: typing.Optional[int] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
     ) -> typing.Union[
@@ -601,6 +604,7 @@ class ApiForget(BaseApi):
             user_secret=user_secret,
             account_id=account_id,
             state=state,
+            days=days,
         )
         return self._get_user_account_orders_oapg(
             query_params=args.query,
